ad_library {

    Postgres-specific database API and utility procs.

    @creation-date 15 Apr 2000
    @author Jon Salz (jsalz@arsdigita.com)
    @cvs-id $Id: 00-database-procs-postgresql.tcl,v 1.43.24.1 2015/09/10 08:21:54 gustafn Exp $
}

# This file is now obsolete.  All procs have been merged into
# 00-database-procs.tcl, so that all supported databases are useable
# with the db_* API all the time, regardless of which database type
# OpenACS is using.  --atp@piskorski.com, 2003/04/09 12:04 EDT

# Local variables:
#    mode: tcl
#    tcl-indent-level: 4
#    indent-tabs-mode: nil
# End:
